@@ -89,8 +89,8 @@ class SpeedySpeechConfig(BaseTTSConfig):
         binary_loss_alpha (float):
             Weight for the binary loss. If set 0, disables the binary loss. Defaults to 1.0.
 
-        binary_align_loss_start_step (int):
-            Start binary alignment loss after this many steps. Defaults to 20000.
+        binary_loss_warmup_epochs (float):
+            Number of epochs to gradually increase the binary loss impact. Defaults to 150.
 
         min_seq_len (int):
             Minimum input sequence length to be used at training.
@@ -150,7 +150,7 @@ class SpeedySpeechConfig(BaseTTSConfig):
     spec_loss_alpha: float = 1.0
     aligner_loss_alpha: float = 1.0
     binary_align_loss_alpha: float = 0.3
-    binary_align_loss_start_step: int = 50000
+    binary_loss_warmup_epochs: int = 150
 
     # overrides
     min_seq_len: int = 13
