@@ -67,14 +67,9 @@ class WN(torch.nn.Module):
         for i in range(num_layers):
             dilation = dilation_rate**i
             padding = int((kernel_size * dilation - dilation) / 2)
-            if i == 0:
-                in_layer = torch.nn.Conv1d(
-                    in_channels, 2 * hidden_channels, kernel_size, dilation=dilation, padding=padding
-                )
-            else:
-                in_layer = torch.nn.Conv1d(
-                    hidden_channels, 2 * hidden_channels, kernel_size, dilation=dilation, padding=padding
-                )
+            in_layer = torch.nn.Conv1d(
+                hidden_channels, 2 * hidden_channels, kernel_size, dilation=dilation, padding=padding
+            )
             in_layer = torch.nn.utils.weight_norm(in_layer, name="weight")
             self.in_layers.append(in_layer)
 
