@@ -111,7 +111,7 @@ class BaseTTS(BaseTrainerModel):
         """Prepare and return `aux_input` used by `forward()`"""
         return {"speaker_id": None, "style_wav": None, "d_vector": None, "language_id": None}
 
-    def get_aux_input_from_test_sentences(self, sentence_info):
+    def get_aux_input_from_test_setences(self, sentence_info):
         if hasattr(self.config, "model_args"):
             config = self.config.model_args
         else:
@@ -134,21 +134,21 @@ class BaseTTS(BaseTrainerModel):
 
         # get speaker  id/d_vector
         speaker_id, d_vector, language_id = None, None, None
-        if self.speaker_manager is not None:
+        if hasattr(self, "speaker_manager"):
             if config.use_d_vector_file:
                 if speaker_name is None:
-                    d_vector = self.speaker_manager.get_random_embedding()
+                    d_vector = self.speaker_manager.get_random_embeddings()
                 else:
                     d_vector = self.speaker_manager.get_d_vector_by_name(speaker_name)
             elif config.use_speaker_embedding:
                 if speaker_name is None:
                     speaker_id = self.speaker_manager.get_random_id()
                 else:
-                    speaker_id = self.speaker_manager.name_to_id[speaker_name]
+                    speaker_id = self.speaker_manager.ids[speaker_name]
 
         # get language id
-        if self.language_manager is not None and config.use_language_embedding and language_name is not None:
-            language_id = self.language_manager.name_to_id[language_name]
+        if hasattr(self, "language_manager") and config.use_language_embedding and language_name is not None:
+            language_id = self.language_manager.ids[language_name]
 
         return {
             "text": text,
@@ -183,7 +183,6 @@ class BaseTTS(BaseTrainerModel):
         attn_mask = batch["attns"]
         waveform = batch["waveform"]
         pitch = batch["pitch"]
-        energy = batch["energy"]
         language_ids = batch["language_ids"]
         max_text_length = torch.max(text_lengths.float())
         max_spec_length = torch.max(mel_lengths.float())
@@ -232,9 +231,7 @@ class BaseTTS(BaseTrainerModel):
             "item_idx": item_idx,
             "waveform": waveform,
             "pitch": pitch,
-            "energy": energy,
             "language_ids": language_ids,
-            "audio_unique_names": batch["audio_unique_names"],
         }
 
     def get_sampler(self, config: Coqpit, dataset: TTSDataset, num_gpus=1):
@@ -289,23 +286,21 @@ class BaseTTS(BaseTrainerModel):
             loader = None
         else:
             # setup multi-speaker attributes
-            if self.speaker_manager is not None:
+            if hasattr(self, "speaker_manager") and self.speaker_manager is not None:
                 if hasattr(config, "model_args"):
-                    speaker_id_mapping = (
-                        self.speaker_manager.name_to_id if config.model_args.use_speaker_embedding else None
-                    )
+                    speaker_id_mapping = self.speaker_manager.ids if config.model_args.use_speaker_embedding else None
                     d_vector_mapping = self.speaker_manager.embeddings if config.model_args.use_d_vector_file else None
                     config.use_d_vector_file = config.model_args.use_d_vector_file
                 else:
-                    speaker_id_mapping = self.speaker_manager.name_to_id if config.use_speaker_embedding else None
+                    speaker_id_mapping = self.speaker_manager.ids if config.use_speaker_embedding else None
                     d_vector_mapping = self.speaker_manager.embeddings if config.use_d_vector_file else None
             else:
                 speaker_id_mapping = None
                 d_vector_mapping = None
 
             # setup multi-lingual attributes
-            if self.language_manager is not None:
-                language_id_mapping = self.language_manager.name_to_id if self.args.use_language_embedding else None
+            if hasattr(self, "language_manager") and self.language_manager is not None:
+                language_id_mapping = self.language_manager.ids if self.args.use_language_embedding else None
             else:
                 language_id_mapping = None
 
@@ -315,8 +310,6 @@ class BaseTTS(BaseTrainerModel):
                 compute_linear_spec=config.model.lower() == "tacotron" or config.compute_linear_spec,
                 compute_f0=config.get("compute_f0", False),
                 f0_cache_path=config.get("f0_cache_path", None),
-                compute_energy=config.get("compute_energy", False),
-                energy_cache_path=config.get("energy_cache_path", None),
                 samples=samples,
                 ap=self.ap,
                 return_wav=config.return_wav if "return_wav" in config else False,
@@ -349,9 +342,9 @@ class BaseTTS(BaseTrainerModel):
             loader = DataLoader(
                 dataset,
                 batch_size=config.eval_batch_size if is_eval else config.batch_size,
-                shuffle=config.shuffle if sampler is None else False,  # if there is no other sampler
+                shuffle=False,  # shuffle is done in the dataset.
                 collate_fn=dataset.collate_fn,
-                drop_last=config.drop_last,  # setting this False might cause issues in AMP training.
+                drop_last=False,  # setting this False might cause issues in AMP training.
                 sampler=sampler,
                 num_workers=config.num_eval_loader_workers if is_eval else config.num_loader_workers,
                 pin_memory=False,
@@ -361,6 +354,7 @@ class BaseTTS(BaseTrainerModel):
     def _get_test_aux_input(
         self,
     ) -> Dict:
+
         d_vector = None
         if self.config.use_d_vector_file:
             d_vector = [self.speaker_manager.embeddings[name]["embedding"] for name in self.speaker_manager.embeddings]
@@ -369,7 +363,7 @@ class BaseTTS(BaseTrainerModel):
         aux_inputs = {
             "speaker_id": None
             if not self.config.use_speaker_embedding
-            else random.sample(sorted(self.speaker_manager.name_to_id.values()), 1),
+            else random.sample(sorted(self.speaker_manager.ids.values()), 1),
             "d_vector": d_vector,
             "style_wav": None,  # TODO: handle GST style input
         }
@@ -392,9 +386,6 @@ class BaseTTS(BaseTrainerModel):
         test_sentences = self.config.test_sentences
         aux_inputs = self._get_test_aux_input()
         for idx, sen in enumerate(test_sentences):
-            if isinstance(sen, list):
-                aux_inputs = self.get_aux_input_from_test_sentences(sen)
-                sen = aux_inputs["text"]
             outputs_dict = synthesis(
                 self,
                 sen,
@@ -428,7 +419,7 @@ class BaseTTS(BaseTrainerModel):
             print(f" > `speakers.pth` is saved to {output_path}.")
             print(" > `speakers_file` is updated in the config.json.")
 
-        if self.language_manager is not None:
+        if hasattr(self, "language_manager") and self.language_manager is not None:
             output_path = os.path.join(trainer.output_path, "language_ids.json")
             self.language_manager.save_ids_to_file(output_path)
             trainer.config.language_ids_file = output_path
